@@ -1,6 +1,6 @@
 # Release information about Select-Shuttle
 
-version = "0.92"
+version = "1.0"
 
 description = """The SelectShuttle widget provides a mechanism for selecting
 multiple values from a list of values by allowing the user to move items
@@ -8,7 +8,10 @@ between two lists. On modern browsers you can also double click an item to
 move it from one list to the other. After the first "move", all entries
 will be sorted automatically accordingly to its "description" on both
 lists. Take a look at the code for SelectShuttleDesc for an example of how
-to use this widget in your code."""
+to use this widget in your code.
+
+This release was greatly based on Alberto Valverde's enhancements and conversion
+to CompoundWidgets."""
 
 author = "Jorge Godoy"
 
